@@ -1,8 +1,8 @@
-#!/usr/local/bin/ruby
+#! /usr/bin/ruby
 
 #==============================================================================#
 # bin/brbexe.rb
-# $Id: brbexe.rb,v 1.3 2003/02/03 05:57:46 yuya Exp $
+# $Id: brbexe.rb,v 1.5 2003/03/06 06:10:04 yuya Exp $
 #==============================================================================#
 
 require 'bruby'
@@ -21,13 +21,16 @@ module BRbExeCommand
 
     inputfile = ARGV[0]
 
+    $KCODE    = options[:kcode]
     BRb.debug = options[:debug]
+
     BRb.loadfile(inputfile)
   end
 
   def self.parse_argv
     parser = GetoptLong.new
     parser.set_options(
+      ['--kcode',  '-K', GetoptLong::REQUIRED_ARGUMENT],
       ['--debug',  '-g', GetoptLong::NO_ARGUMENT],
       ['--help',   '-h', GetoptLong::NO_ARGUMENT]
     )
@@ -37,6 +40,7 @@ module BRbExeCommand
       options[name.sub(/^--/, '').intern] = argument
     }
 
+    options[:kcode] = 'n' if options[:kcode].nil?
     options[:debug] = !!options[:debug]
     options[:help]  = !!options[:help]
 
@@ -49,6 +53,7 @@ module BRbExeCommand
     STDERR.puts "bRuby #{BRb::VERSION}"
     STDERR.puts "Usage: brbexe.rb [options] file"
     STDERR.puts "Options:"
+    STDERR.puts "  -K  --kcode    specifies KANJI code-set."
     STDERR.puts "  -g  --debug    enable debug mode."
     STDERR.puts "  -h  --help     display this information."
     exit(1)
