@@ -1,8 +1,8 @@
-#!/usr/local/bin/ruby
+#! /usr/bin/ruby
 
 #==============================================================================#
 # bin/brbverify.rb
-# $Id: brbverify.rb,v 1.3 2003/02/03 05:57:46 yuya Exp $
+# $Id: brbverify.rb,v 1.5 2003/03/06 06:10:04 yuya Exp $
 #==============================================================================#
 
 require 'bruby'
@@ -19,20 +19,27 @@ module BRbVerifyCommand
       print_usage
     end
 
-    intputfile = ARGV[0]
+    $KCODE    = options[:kcode]
+    BRb.debug = options[:debug]
 
-    if BRb.verifyfile(intputfile)
-      puts 'ok'
-      exit(0)
-    else
-      puts 'ng'
-      exit(1)
-    end
+    exit_code = 0
+
+    ARGV.each { |intputfile|
+      if BRb.verifyfile(intputfile)
+        puts "#{intputfile} : ok"
+      else
+        puts '#{intputfile} : ng'
+        exit_code = 1
+      end
+    }
+
+    exit(exit_code)
   end
 
   def self.parse_argv
     parser = GetoptLong.new
     parser.set_options(
+      ['--kcode',  '-K', GetoptLong::REQUIRED_ARGUMENT],
       ['--debug',  '-g', GetoptLong::NO_ARGUMENT],
       ['--help',   '-h', GetoptLong::NO_ARGUMENT]
     )
@@ -42,6 +49,7 @@ module BRbVerifyCommand
       options[name.sub(/^--/, '').intern] = argument
     }
 
+    options[:kcode] = 'n' if options[:kcode].nil?
     options[:debug] = !!options[:debug]
     options[:help]  = !!options[:help]
 
@@ -54,6 +62,7 @@ module BRbVerifyCommand
     STDERR.puts "bRuby #{BRb::VERSION}"
     STDERR.puts "Usage: brbverify.rb [options] file"
     STDERR.puts "Options:"
+    STDERR.puts "  -K  --kcode    specifies KANJI code-set."
     STDERR.puts "  -g  --debug    enable debug mode."
     STDERR.puts "  -h  --help     display this information."
     exit(1)
