@@ -1,4 +1,4 @@
-// $Id: BRbDebug.h,v 1.8 2002/12/18 06:46:50 yuya Exp $
+// $Id: BRbDebug.h,v 1.10 2003/02/21 02:19:10 yuya Exp $
 
 #ifndef _BRbDebug_h_
 #define _BRbDebug_h_
@@ -17,15 +17,16 @@ class BRbDebug
 {
 
 public:
-	BRbDebug(bool debug, FILE* out = stderr, BRB_EXCEPTION excpfunc = NULL);
+	BRbDebug(bool debug, FILE* out, VALUE exception);
 	virtual ~BRbDebug();
 
 public:
 	virtual void printf(const char* format, ...);
-	virtual void dumpnode(NODE* node);
 	virtual void raise(const char* fmt, ...);
+	virtual void dumpnode(NODE* node);
 
 protected:
+#ifdef DEBUG
 	virtual void p(const char *fmt, ...);
 	virtual void lp(int indent, const char* fmt, ...);
 	virtual void lpdump(int indent, char *name, NODE *node);
@@ -33,11 +34,12 @@ protected:
 	virtual VALUE noex_name(int flag);
 	virtual void dump_literal(long lit, int level);
 	virtual void dump_node(NODE* n, int level);
+#endif
 
 protected:
 	bool  m_debug;
 	FILE* m_out;
-	BRB_EXCEPTION m_excpfunc;
+	VALUE m_exception;
 
 };
 
