@@ -1,4 +1,4 @@
-// $Id: bruby.cpp,v 1.10 2003/02/11 16:17:26 yuya Exp $
+// $Id: bruby.cpp,v 1.11 2003/03/06 03:39:00 yuya Exp $
 
 #include "BRbBase.h"
 #include "BRb.h"
@@ -6,12 +6,12 @@
 ////////////////////////////////////////////////////////////////////////////////
 
 #ifdef BRB_WRITER
-static VALUE rb_brb_s_dump(VALUE obj, VALUE source, VALUE filename);
+static VALUE rb_brb_s_dump(int argc, VALUE *argv, VALUE obj);
 static VALUE rb_brb_s_dumpfile(VALUE obj, VALUE filename);
 //static VALUE rb_brb_s_dumpproc(VALUE obj, VALUE proc);
 #endif
 #ifdef BRB_READER
-static VALUE rb_brb_s_load(VALUE obj, VALUE code);
+static VALUE rb_brb_s_load(int argc, VALUE *argv, VALUE obj);
 static VALUE rb_brb_s_loadfile(VALUE obj, VALUE filename);
 //static VALUE rb_brb_s_loadproc(VALUE obj, VALUE code);
 #endif
@@ -36,10 +36,16 @@ static bool g_debug = false;
 #ifdef BRB_WRITER
 
 static VALUE
-rb_brb_s_dump(VALUE obj, VALUE source, VALUE filename)
+rb_brb_s_dump(int argc, VALUE *argv, VALUE obj)
 {
+	VALUE source, filename;
+	if ( ::rb_scan_args(argc, argv, "11", &source, &filename) == 1 ) {
+		filename = ::rb_str_new2("(bruby)");
+	}
+
 	Check_Type(source,   T_STRING);
 	Check_Type(filename, T_STRING);
+
 	return BRb::dumpcode(source, filename, g_debug, rb_eBRbException);
 }
 
@@ -68,10 +74,17 @@ rb_brb_s_dumpproc(VALUE obj, VALUE proc)
 #ifdef BRB_READER
 
 static VALUE
-rb_brb_s_load(VALUE obj, VALUE code)
+rb_brb_s_load(int argc, VALUE *argv, VALUE obj)
 {
+	VALUE code, filename;
+	if ( ::rb_scan_args(argc, argv, "11", &code, &filename) == 1 ) {
+		filename = ::rb_str_new2("(bruby)");
+	}
+
 	Check_Type(code, T_STRING);
-	return BRb::loadcode(code, ::rb_str_new2("(bruby)"), g_debug, rb_eBRbException);
+	Check_Type(filename, T_STRING);
+
+	return BRb::loadcode(code, filename, g_debug, rb_eBRbException);
 }
 
 static VALUE
@@ -131,12 +144,12 @@ Init_bruby()
 	rb_mBRb = ::rb_define_module("BRb");
 	::rb_define_const(rb_mBRb, "VERSION", ::rb_str_new2(BRB_VERSION));
 #ifdef BRB_WRITER
-	::rb_define_singleton_method(rb_mBRb, "dump",       (VALUE(*)(...))rb_brb_s_dump,       2);
+	::rb_define_singleton_method(rb_mBRb, "dump",       (VALUE(*)(...))rb_brb_s_dump,       -1);
 	::rb_define_singleton_method(rb_mBRb, "dumpfile",   (VALUE(*)(...))rb_brb_s_dumpfile,   1);
 //	::rb_define_singleton_method(rb_mBRb, "dumpproc",   (VALUE(*)(...))rb_brb_s_dumpproc,   1);
 #endif
 #ifdef BRB_READER
-	::rb_define_singleton_method(rb_mBRb, "load",       (VALUE(*)(...))rb_brb_s_load,       1);
+	::rb_define_singleton_method(rb_mBRb, "load",       (VALUE(*)(...))rb_brb_s_load,       -1);
 	::rb_define_singleton_method(rb_mBRb, "loadfile",   (VALUE(*)(...))rb_brb_s_loadfile,   1);
 //	::rb_define_singleton_method(rb_mBRb, "loadproc",   (VALUE(*)(...))rb_brb_s_loadproc,   1);
 #endif
