@@ -1,8 +1,8 @@
-#! /usr/bin/ruby
+#! /usr/bin/ruby -Ks
 
 #==============================================================================#
 # test-complex.rb
-# $Id: test-complex.rb,v 1.8 2003/02/10 09:22:15 yuya Exp $
+# $Id: test-complex.rb,v 1.14 2003/03/06 09:07:23 yuya Exp $
 #==============================================================================#
 
 require 'testcase'
@@ -23,6 +23,11 @@ class ComplexTest < BRbTestCase
     'class_class_method',
     'class_instance_method',
     'bignum',
+    'bug_report1',
+    'bug_report2',
+    'bug_report3',
+    'bug_report4',
+    'bug_report5',
   ].each { |name|
     self.module_eval(<<-EOS)
       def test_#{name}
